Contributing
================

 
Contributions such as bug reports or pull requests and any other 
user feedback are much appreciated. Development takes place on 
`github <https://github.com/dr-leo/pandaSDMX>`_.
There is also a low traffic 
`Mailing list <https://groups.google.com/forum/?hl=en#!forum/sdmx-python>`_.   


  

